package games.strategy.triplea.ui.history;

import games.strategy.engine.history.HistoryNode;

public interface IHistoryDetailsPanel {
  public void render(final HistoryNode node);
}
